pub enum SearchEmailsFilterQuery {
And(Box<SearchEmailsFilterQuery>, Box<SearchEmailsFilterQuery>),
Or(Box<SearchEmailsFilterQuery>, Box<SearchEmailsFilterQuery>),
Not(Box<SearchEmailsFilterQuery>),
Date(NaiveDate),
AfterDate(NaiveDate),
From(String),
To(String),
Subject(String),
Body(String),
Flag(Flag),
}search only.Expand description
The search emails filter query.
Composed of 3 operators (and, or, not) and 7 conditions (date,
after date, from, to, subject, body, flag). All date-related
conditions are anchored to the Date: header (sent-at), never to
the server-side received-at timestamp.
Variants
And(Box<SearchEmailsFilterQuery>, Box<SearchEmailsFilterQuery>)
Filter emails that match both given conditions.
Or(Box<SearchEmailsFilterQuery>, Box<SearchEmailsFilterQuery>)
Filter emails that match one of the two given conditions.
Not(Box<SearchEmailsFilterQuery>)
Filter emails that do not match the given condition.
Date(NaiveDate)
Filter emails where the Date: header of the message matches
the given date.
Only the year, the month and the day are taken into consideration.
AfterDate(NaiveDate)
Filter emails where the Date: header of the message is
strictly greater than the given date.
For example, for 2024-01-01 it matches messages with a date
starting from 2024-01-02 and above. Only the year, the month
and the day are taken into consideration.
From(String)
Filter emails where the From: header of the message contains
the given pattern.
To(String)
Filter emails where the To: header of the message contains
the given pattern.
Subject(String)
Filter emails where the Subject: header of the message
contains the given pattern.
Body(String)
Filter emails where one of the text bodies of the message contains the given pattern.
Flag(Flag)
Filter emails where the given flag is included in the email envelope flags.